@@ -9,9 +9,10 @@ import os
 
 def get_ecses():
     cfg = ado_ini.read_cfg()
+    print('regions:',cfg.get('default', 'regionids').split(','))
     cli = ali_cli.AliCli(cfg.get('default', 'accesskeyid'),
                          cfg.get('default', 'accesskeysecret'),
-                         cfg.get('default', 'regionids').split(', '))
+                         cfg.get('default', 'regionids').split(','))
     return [ecs for ecs in cli.ecses_iterator()]
 
 
@@ -22,13 +23,13 @@ def cli():
         try:
             os.system('clear')
             for i in range(len(ecses)):
-                print(i + 1, ':', ecses[i])
+                print(''.join([str(i+1), ':', ecses[i].__str__()]))
             index = int(input('请选择ECS序号:'))
-            sship = ecses[i].ip
+            sship = ecses[int(index)].ip
             # sship = '127.0.0.1'
             print('ecs',':',ecses[i].__str__())
             os.system('ssh root@' + sship)
-        except:
+        except SyntaxError as e:
             pass
 
 
