@@ -1,7 +1,8 @@
 # -*-coding=utf-8-*-
 
-from configparser import ConfigParser
 import os
+import ConfigParser
+
 ini_file = os.path.join(os.path.expanduser('~'), '.ado/config.ini')
 ini_file_dir=os.path.dirname(ini_file)
 
@@ -9,7 +10,7 @@ if not os.path.exists(ini_file_dir):
     os.makedirs(ini_file_dir)
 
 if not os.path.exists(ini_file):
-    cfg = ConfigParser()
+    cfg = ConfigParser.RawConfigParser()
     cfg.add_section('default')
     cfg.set('default','accesskeyid','')
     cfg.set('default','accesskeysecret','')
@@ -19,7 +20,7 @@ if not os.path.exists(ini_file):
         cfg.write(f)
 
 def read_cfg():
-    cfg = ConfigParser()
+    cfg = ConfigParser.RawConfigParser()
     cfg.read(ini_file)
     return cfg
 
